==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/File/NewFile/ts/NewFile_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../CloseDialog.ui" line="+14"/>
        <source>Closing Drawing...</source>
        <translation>Cerrando el dibujo...</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../MdiChildEmpty.ui" line="+20"/>
        <source>Untitled</source>
        <translation>Sin título</translation>
    </message>
</context>
<context>
    <name>NewFile</name>
    <message>
        <source>Untitled %1 [*]</source>
        <translation type="obsolete">Sin título %1 [*]</translation>
    </message>
    <message>
        <location filename="../NewFile.js" line="+120"/>
        <source>Loading...</source>
        <translation>Cargando...</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Import Error</source>
        <translation>Error de importación</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cannot open file</source>
        <translation>No se puede abrir el archivo</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No suitable Importer found. Please check file format and extension.</source>
        <translation>Ningún importador adecuado encontrado. Por favor revise el formato de archivo y extensión.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Please check your access rights, the file format and file extension.</source>
        <translation>Por favor, compruebe sus derechos de acceso, el formato de archivo y extensión de archivo.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>File is empty.</source>
        <translation>El archivo está vacío.</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Opened drawing:</source>
        <translation>Dibujo Abierto:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <location line="+92"/>
        <source>Untitled %1</source>
        <translation>Sin título %1</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>read-only</source>
        <translation>Sólo lectura</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Do you want to save the changes you made in&lt;br&gt;the document &apos;%1&apos;?</source>
        <translation>¿Desea guardar los cambios realizados en el&lt;br&gt;documento &apos;%1&apos;?</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Los cambios se perderán si no los salvará.</translation>
    </message>
    <message>
        <location filename="../NewFileInit.js" line="+2"/>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/File/NewFile/ts/NewFile_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../CloseDialog.ui" line="+14"/>
        <source>Closing Drawing...</source>
        <translation>Cerrando el dibujo...</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../MdiChildEmpty.ui" line="+20"/>
        <source>Untitled</source>
        <translation>Sin título</translation>
    </message>
</context>
<context>
    <name>NewFile</name>
    <message>
        <source>Untitled %1 [*]</source>
        <translation type="obsolete">Sin título %1 [*]</translation>
    </message>
    <message>
        <location filename="../NewFile.js" line="+114"/>
        <source>Opening drawing:</source>
        <translation>Abriendo el dibujo:</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="vanished">Cargando...</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Import Error</source>
        <translation>Error de importación</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Cannot open file</source>
        <translation>No se puede abrir el archivo</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No suitable Importer found. Please check file format and extension.</source>
        <translation>Ningún importador adecuado encontrado. Por favor revise el formato de archivo y extensión.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>File not found.</source>
        <translation>Archivo no encontrado.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Please check your access rights, the file format and file extension.</source>
        <translation>Por favor, compruebe sus derechos de acceso, el formato de archivo y extensión de archivo.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Import failed.</source>
        <translation>La importación ha fallado.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>File is empty.</source>
        <translation>El archivo está vacío.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Drawing loaded successfully:</source>
        <translation>Dibujo cargó correctamente:</translation>
    </message>
    <message>
        <source>Opened drawing:</source>
        <translation type="vanished">Dibujo Abierto:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <location line="+124"/>
        <source>Untitled %1</source>
        <translation>Sin título %1</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>read-only</source>
        <translation>Sólo lectura</translation>
    </message>
    <message>
        <location line="+53"/>
        <source>Do you want to save the changes you made in&lt;br&gt;the document &apos;%1&apos;?</source>
        <translation>¿Desea guardar los cambios realizados en el&lt;br&gt;documento &apos;%1&apos;?</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Los cambios se perderán si no los salvará.</translation>
    </message>
    <message>
        <location filename="../NewFileInit.js" line="+2"/>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
</context>
</TS>
